zip

package
v0.10.44 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Zip

func Zip(repository string, tozip []string) error

Create a Zip file `{repository}.zip` and recursively add the contents of all paths in the `tozip` array to it. Deletes the original contents of `repository` such that only the newly created Zip file remains.

Types

This section is empty.

Jump to